# FastLMI

A work-in-progress package to quickly define and iterate on language model interfaces (LMIs).

## Build and Publish

`fastlmi` uses Hatchling to build.

```shell
python -m build
python -m twine upload dist/*
```
